@@ -5,12 +5,15 @@
 
 #include <QPalette>
 
+#include <optional>
+
 QT_FORWARD_DECLARE_CLASS(QString)
 
 namespace QtUtilities {
 
 QT_UTILITIES_EXPORT bool openLocalFileOrDir(const QString &path);
 QT_UTILITIES_EXPORT bool isPaletteDark(const QPalette &palette = QPalette());
+QT_UTILITIES_EXPORT std::optional<bool> isDarkModeEnabled();
 
 } // namespace QtUtilities
 
