@@ -68,6 +68,11 @@ void cleanup()
  */
 namespace TranslationFiles {
 
+/*!
+ * \brief The translators installed via the load-functions in this namespace.
+ */
+static QList<QTranslator *> translators;
+
 /*!
  * \brief Allows to set an additional search path for translation files.
  * \remarks This path is considered *before* the default directories.
@@ -132,6 +137,7 @@ void loadQtTranslationFile(initializer_list<QString> repositoryNames, const QStr
             || qtTranslator->load(fileName, path = QStringLiteral("../share/qt/translations"))
             || qtTranslator->load(fileName, path = QStringLiteral(":/translations"))) {
             QCoreApplication::installTranslator(qtTranslator);
+            translators.append(qtTranslator);
             if (debugTranslations) {
                 cerr << "Loading translation file for Qt repository \"" << repoName.toLocal8Bit().data() << "\" and the locale \""
                      << localeName.toLocal8Bit().data() << "\" from \"" << path.toLocal8Bit().data() << "\"." << endl;
@@ -223,13 +229,13 @@ void loadApplicationTranslationFile(const QString &configName, const QString &ap
     QString path;
     if ((!additionalTranslationFilePath().isEmpty() && appTranslator->load(fileName, path = additionalTranslationFilePath()))
         || appTranslator->load(fileName, path = QStringLiteral(".")) || appTranslator->load(fileName, path = QStringLiteral("../") % directoryName)
-        || appTranslator->load(fileName, path = QStringLiteral("../") % directoryName)
         || appTranslator->load(fileName, path = QStringLiteral("../../") % directoryName)
         || appTranslator->load(fileName, path = QStringLiteral("./translations"))
         || appTranslator->load(fileName, path = QStringLiteral("../share/") % directoryName % QStringLiteral("/translations"))
         || appTranslator->load(fileName, path = QStringLiteral(APP_INSTALL_PREFIX "/share/") % directoryName % QStringLiteral("/translations"))
         || appTranslator->load(fileName, path = QStringLiteral(":/translations"))) {
         QCoreApplication::installTranslator(appTranslator);
+        translators.append(appTranslator);
         if (qEnvironmentVariableIsSet("QT_DEBUG_TRANSLATIONS")) {
             logTranslationEvent("Loading", configName, applicationName, localeName, path);
         }
@@ -267,6 +273,18 @@ void loadApplicationTranslationFile(const QString &configName, const std::initia
         loadApplicationTranslationFile(configName, applicationName, localeName);
     }
 }
+
+/*!
+ * \brief Clears all translation files previously loaded via the load-functions in this namespace.
+ */
+void clearTranslationFiles()
+{
+    for (auto *const translator : translators) {
+        QCoreApplication::removeTranslator(translator);
+    }
+    translators.clear();
+}
+
 } // namespace TranslationFiles
 
 /*!
@@ -313,10 +331,13 @@ bool hasCoreApp()
  */
 void setupCommonQtApplicationAttributes()
 {
-    // enable dark window frame on Windows if the configured color palette is dark (supported as of Qt 6.4)
-    // see https://bugreports.qt.io/browse/QTBUG-72028?focusedCommentId=677819#comment-677819
-#if defined(Q_OS_WINDOWS) && (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
-    if (QLibraryInfo::version() >= QVersionNumber(6, 4, 0) && !qEnvironmentVariableIsSet("QT_QPA_PLATFORM")) {
+    // enable dark window frame on Windows if the configured color palette is dark
+    // - supported as of Qt 6.4; no longer required as of Qt 6.5
+    // - see https://bugreports.qt.io/browse/QTBUG-72028?focusedCommentId=677819#comment-677819
+    //   and https://www.qt.io/blog/dark-mode-on-windows-11-with-qt-6.5
+#if defined(Q_OS_WINDOWS) && (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)) && (QT_VERSION < QT_VERSION_CHECK(6, 5, 0))
+    if (const auto qtVersion = QLibraryInfo::version();
+        qtVersion >= QVersionNumber(6, 4, 0) && qtVersion < QVersionNumber(6, 5, 0) && !qEnvironmentVariableIsSet("QT_QPA_PLATFORM")) {
         qputenv("QT_QPA_PLATFORM", "windows:darkmode=1");
     }
 #endif
@@ -369,6 +390,27 @@ std::unique_ptr<QSettings> getSettings(const QString &organization, const QStrin
     return settings;
 }
 
+/*!
+ * \brief Returns an error message for the specified \a settings or an empty string if there's no error.
+ */
+QString errorMessageForSettings(const QSettings &settings)
+{
+    auto errorMessage = QString();
+    switch (settings.status()) {
+    case QSettings::NoError:
+        return QString();
+    case QSettings::AccessError:
+        errorMessage = QCoreApplication::translate("QtUtilities", "unable to access file");
+        break;
+    case QSettings::FormatError:
+        errorMessage = QCoreApplication::translate("QtUtilities", "file has invalid format");
+        break;
+    default:
+        errorMessage = QCoreApplication::translate("QtUtilities", "unknown error");
+    }
+    return QCoreApplication::translate("QtUtilities", "Unable to sync settings from \"%1\": %2").arg(settings.fileName(), errorMessage);
+}
+
 // namespace ApplicationInstances
 
 } // namespace QtUtilities
