@@ -53,6 +53,7 @@ QT_UTILITIES_EXPORT void loadApplicationTranslationFile(const QString &configNam
 QT_UTILITIES_EXPORT void loadApplicationTranslationFile(const QString &configName, const std::initializer_list<QString> &applicationNames);
 QT_UTILITIES_EXPORT void loadApplicationTranslationFile(
     const QString &configName, const std::initializer_list<QString> &applicationNames, const QString &localeName);
+QT_UTILITIES_EXPORT void clearTranslationFiles();
 } // namespace TranslationFiles
 
 namespace ApplicationInstances {
@@ -68,6 +69,7 @@ QT_UTILITIES_EXPORT bool hasCoreApp();
 
 QT_UTILITIES_EXPORT void setupCommonQtApplicationAttributes();
 QT_UTILITIES_EXPORT std::unique_ptr<QSettings> getSettings(const QString &organization, const QString &application = QString());
+QT_UTILITIES_EXPORT QString errorMessageForSettings(const QSettings &settings);
 
 } // namespace QtUtilities
 
