@@ -9,10 +9,18 @@
         <translation>Text löschen</translation>
     </message>
 </context>
+<context>
+    <name>QtConfigArguments</name>
+    <message>
+        <location filename="../resources/qtconfigarguments.cpp" line="193"/>
+        <source>This application requires Windows 10, version 1809 or newer. The current Windows version is older so the application might not work correctly.</source>
+        <translation>Diese Anwendung benötigt mindestens Windows 10, version 1809 oder neuer. Die momentane Windows-Version ist älter. Deshalb wird die Anwendung möglicherweise nicht richtig funktionieren.</translation>
+    </message>
+</context>
 <context>
     <name>QtGui::QtLanguageOptionPage</name>
     <message>
-        <location filename="../settingsdialog/qtsettings.cpp" line="367"/>
+        <location filename="../settingsdialog/qtsettings.cpp" line="566"/>
         <source>recognized by Qt as</source>
         <translation>von Qt erkannt als</translation>
     </message>
@@ -20,15 +28,39 @@
 <context>
     <name>QtGui::QtOptionCategory</name>
     <message>
-        <location filename="../settingsdialog/qtsettings.cpp" line="213"/>
+        <location filename="../settingsdialog/qtsettings.cpp" line="420"/>
         <source>Qt</source>
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>QtUtilities</name>
+    <message>
+        <location filename="../resources/resources.cpp" line="403"/>
+        <source>unable to access file</source>
+        <translation>Zugriff auf die Datei ist nicht möglich</translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="406"/>
+        <source>file has invalid format</source>
+        <translation>Datei hat ungültiges Format</translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="409"/>
+        <source>unknown error</source>
+        <translation>unbekannter Fehler</translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="411"/>
+        <source>Unable to sync settings from &quot;%1&quot;: %2</source>
+        <translation>Settings können nicht unter &quot;%1&quot; synchronisiert werden: %2</translation>
+    </message>
+</context>
 <context>
     <name>QtUtilities::AboutDialog</name>
     <message>
         <location filename="../aboutdialog/aboutdialog.ui" line="24"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="139"/>
         <source>About</source>
         <translation>Über</translation>
     </message>
@@ -67,22 +99,22 @@
         <translation type="vanished">verwendet Qt</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="61"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="62"/>
         <source>developed by %1</source>
         <translation>entwickelt von %1</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="71"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
         <source>Linked against:</source>
         <translation>Gegen folgende Bibliotheken gelinkt:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="80"/>
         <source>For updates and bug reports visit the &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;project website&lt;/a&gt;.</source>
         <translation>Für Aktualisierung und Melden von Fehlern besuche die &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;Webseite des Projekts&lt;/a&gt;.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="91"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="99"/>
         <source>Using &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</source>
         <translation>Verwendet &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</translation>
     </message>
@@ -92,8 +124,8 @@
     <message>
         <location filename="../enterpassworddialog/enterpassworddialog.ui" line="12"/>
         <location filename="../enterpassworddialog/enterpassworddialog.ui" line="51"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="190"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="205"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
         <source>Enter the password</source>
         <translation>Passwort eingeben</translation>
     </message>
@@ -138,28 +170,28 @@
         <translation>Bestätigen</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="190"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="205"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
         <source>Enter the new password</source>
         <translation>Neues Passwort festlegen</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="290"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="289"/>
         <source>You didn&apos;t enter a user name.</source>
         <translation>Es wurde kein Benutzername eingegeben.</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="292"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="291"/>
         <source>You didn&apos;t enter a password.</source>
         <translation>Es wurde kein Passwort eingegeben.</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="297"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="296"/>
         <source>You have to enter the new password twice to ensure you enterd it correct.</source>
         <translation>Um sicher zu stellen, dass das neue Passwort richtig eingegeben wurde, muss es zweimal eingegeben werden.</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="300"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="299"/>
         <source>You mistyped the password.</source>
         <translation>Erstes und zweites Passwort stimmen nicht überein.</translation>
     </message>
@@ -192,52 +224,52 @@
         <translation>Einfach</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="45"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="46"/>
         <source>Save…</source>
         <translation>Speichern…</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="47"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="48"/>
         <source>Load…</source>
         <translation>Laden…</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="143"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
         <source>Color palette configuration (*.ini)</source>
         <translation>Farbpalettenkonfiguration (*.ini)</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="150"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="162"/>
         <source>Unable to load &quot;%1&quot;.</source>
         <translation>Fehler beim Laden von &quot;%1&quot;.</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="167"/>
         <source>&quot;%1&quot; does not contain a valid palette.</source>
         <translation>&quot;%1&quot; enthält keine gültige Farbpalette.</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="168"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="180"/>
         <source>Unable to write &quot;%1&quot;.</source>
         <translation>Fehler beim Schreiben von &quot;%1&quot;.</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="176"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="188"/>
         <source>Load palette</source>
         <translation>Palette laden</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="186"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
         <source>Error reading palette</source>
         <translation>Fehler beim Einlesen der Palette</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="192"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="206"/>
         <source>Save palette</source>
         <translation>Palette speichern</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="214"/>
         <source>Error writing palette</source>
         <translation>Fehler beim Schreiben der Palette</translation>
     </message>
@@ -245,22 +277,22 @@
 <context>
     <name>QtUtilities::PaletteModel</name>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="417"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="416"/>
         <source>Color Role</source>
         <translation>Farbrolle</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="419"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="418"/>
         <source>Active</source>
         <translation>Aktiv</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="421"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="420"/>
         <source>Inactive</source>
         <translation>Inaktiv</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="423"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="422"/>
         <source>Disabled</source>
         <translation>Deaktiviert</translation>
     </message>
@@ -268,24 +300,24 @@
 <context>
     <name>QtUtilities::PathSelection</name>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="56"/>
-        <location filename="../widgets/pathselection.cpp" line="76"/>
+        <location filename="../widgets/pathselection.cpp" line="87"/>
+        <location filename="../widgets/pathselection.cpp" line="144"/>
         <source>Select ...</source>
         <translation>Wählen ...</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="81"/>
+        <location filename="../widgets/pathselection.cpp" line="92"/>
         <source>Open</source>
         <translation>Öffnen</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="84"/>
+        <location filename="../widgets/pathselection.cpp" line="95"/>
         <source>Explore</source>
         <translation>Im Dateibrowser öffnen</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="120"/>
-        <location filename="../widgets/pathselection.cpp" line="122"/>
+        <location filename="../widgets/pathselection.cpp" line="131"/>
+        <location filename="../widgets/pathselection.cpp" line="133"/>
         <source>Select path</source>
         <translation>Pfad auswählen</translation>
     </message>
@@ -475,12 +507,12 @@ Außerdem werden sie vielleicht vom QPA plugin überschrieben und funktionieren
         <translation></translation>
     </message>
     <message>
-        <location filename="../settingsdialog/settingsdialog.cpp" line="285"/>
+        <location filename="../settingsdialog/settingsdialog.cpp" line="320"/>
         <source>&lt;p&gt;&lt;b&gt;Errors occurred when applying changes:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;Beim Anwenden der Einstellungen sind Fehler aufgetreten:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</translation>
     </message>
     <message>
-        <location filename="../settingsdialog/settingsdialog.cpp" line="290"/>
+        <location filename="../settingsdialog/settingsdialog.cpp" line="325"/>
         <source>unknown error</source>
         <translation>unbekannter Fehler</translation>
     </message>
@@ -492,22 +524,22 @@ Außerdem werden sie vielleicht vom QPA plugin überschrieben und funktionieren
 <context>
     <name>Utilities::windowTitle</name>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="34"/>
+        <location filename="../misc/dialogutils.cpp" line="36"/>
         <source>Unsaved - %1</source>
         <translation>Nicht gespeichert - %1</translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="37"/>
+        <location filename="../misc/dialogutils.cpp" line="39"/>
         <source>%1 - %2 - %3</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="42"/>
+        <location filename="../misc/dialogutils.cpp" line="44"/>
         <source>*Unsaved - %1</source>
         <translation>*Nicht gespeichert - %1</translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="45"/>
+        <location filename="../misc/dialogutils.cpp" line="47"/>
         <source>*%1 - %2 - %3</source>
         <translation></translation>
     </message>
