@@ -9,10 +9,18 @@
         <translation>清除</translation>
     </message>
 </context>
+<context>
+    <name>QtConfigArguments</name>
+    <message>
+        <location filename="../resources/qtconfigarguments.cpp" line="193"/>
+        <source>This application requires Windows 10, version 1809 or newer. The current Windows version is older so the application might not work correctly.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QtGui::QtLanguageOptionPage</name>
     <message>
-        <location filename="../settingsdialog/qtsettings.cpp" line="367"/>
+        <location filename="../settingsdialog/qtsettings.cpp" line="566"/>
         <source>recognized by Qt as</source>
         <translation>被 Qt 识别为</translation>
     </message>
@@ -20,15 +28,39 @@
 <context>
     <name>QtGui::QtOptionCategory</name>
     <message>
-        <location filename="../settingsdialog/qtsettings.cpp" line="213"/>
+        <location filename="../settingsdialog/qtsettings.cpp" line="420"/>
         <source>Qt</source>
         <translation>Qt</translation>
     </message>
 </context>
+<context>
+    <name>QtUtilities</name>
+    <message>
+        <location filename="../resources/resources.cpp" line="403"/>
+        <source>unable to access file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="406"/>
+        <source>file has invalid format</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="409"/>
+        <source>unknown error</source>
+        <translation type="unfinished">未知错误</translation>
+    </message>
+    <message>
+        <location filename="../resources/resources.cpp" line="411"/>
+        <source>Unable to sync settings from &quot;%1&quot;: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QtUtilities::AboutDialog</name>
     <message>
         <location filename="../aboutdialog/aboutdialog.ui" line="24"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="139"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
@@ -63,22 +95,22 @@
         <translation>使用 Qt</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="61"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="62"/>
         <source>developed by %1</source>
         <translation>由 %1 开发</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="71"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
         <source>Linked against:</source>
         <translation>链接到：</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="75"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="80"/>
         <source>For updates and bug reports visit the &lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: palette(link);&quot;&gt;project website&lt;/a&gt;.</source>
         <translation>有关更新和错误报告，请访问&lt;a href=&quot;%1&quot; style=&quot;text-decoration: underline; color: Palette(link);&quot;&gt;项目网站&lt;/a&gt;。</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/aboutdialog.cpp" line="91"/>
+        <location filename="../aboutdialog/aboutdialog.cpp" line="99"/>
         <source>Using &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</source>
         <translation>使用 &lt;a href=&quot;qtversion&quot;&gt;Qt %1&lt;/a&gt;</translation>
     </message>
@@ -88,8 +120,8 @@
     <message>
         <location filename="../enterpassworddialog/enterpassworddialog.ui" line="12"/>
         <location filename="../enterpassworddialog/enterpassworddialog.ui" line="51"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="190"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="205"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
         <source>Enter the password</source>
         <translation>输入密码</translation>
     </message>
@@ -134,28 +166,28 @@
         <translation>确认</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="190"/>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="205"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="183"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="198"/>
         <source>Enter the new password</source>
         <translation>输入新密码</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="290"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="289"/>
         <source>You didn&apos;t enter a user name.</source>
         <translation>您没有输入用户名。</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="292"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="291"/>
         <source>You didn&apos;t enter a password.</source>
         <translation>您没有输入密码。</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="297"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="296"/>
         <source>You have to enter the new password twice to ensure you enterd it correct.</source>
         <translation>您必须输入两次新密码以确保输入正确。</translation>
     </message>
     <message>
-        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="300"/>
+        <location filename="../enterpassworddialog/enterpassworddialog.cpp" line="299"/>
         <source>You mistyped the password.</source>
         <translation>您输错了密码。</translation>
     </message>
@@ -188,52 +220,52 @@
         <translation>快</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="45"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="46"/>
         <source>Save…</source>
         <translation>保存…</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="47"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="48"/>
         <source>Load…</source>
         <translation>加载…</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="143"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
         <source>Color palette configuration (*.ini)</source>
         <translation>调色板配置 (*.ini)</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="150"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="162"/>
         <source>Unable to load &quot;%1&quot;.</source>
         <translation>无法加载 &quot;%1&quot;。</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="155"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="167"/>
         <source>&quot;%1&quot; does not contain a valid palette.</source>
         <translation>&quot;%1&quot;  不包含有效的调色板。</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="168"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="180"/>
         <source>Unable to write &quot;%1&quot;.</source>
         <translation>无法写入 &quot;%1&quot;.。</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="176"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="188"/>
         <source>Load palette</source>
         <translation>加载调色板</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="186"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
         <source>Error reading palette</source>
         <translation>读取调色板时出错</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="192"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="206"/>
         <source>Save palette</source>
         <translation>保存调色板</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="200"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="214"/>
         <source>Error writing palette</source>
         <translation>写入调色板时出错</translation>
     </message>
@@ -241,22 +273,22 @@
 <context>
     <name>QtUtilities::PaletteModel</name>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="417"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="416"/>
         <source>Color Role</source>
         <translation>颜色角色</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="419"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="418"/>
         <source>Active</source>
         <translation>激活</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="421"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="420"/>
         <source>Inactive</source>
         <translation>未激活</translation>
     </message>
     <message>
-        <location filename="../paletteeditor/paletteeditor.cpp" line="423"/>
+        <location filename="../paletteeditor/paletteeditor.cpp" line="422"/>
         <source>Disabled</source>
         <translation>已禁用</translation>
     </message>
@@ -264,24 +296,24 @@
 <context>
     <name>QtUtilities::PathSelection</name>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="56"/>
-        <location filename="../widgets/pathselection.cpp" line="76"/>
+        <location filename="../widgets/pathselection.cpp" line="87"/>
+        <location filename="../widgets/pathselection.cpp" line="144"/>
         <source>Select ...</source>
         <translation>选择 ...</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="81"/>
+        <location filename="../widgets/pathselection.cpp" line="92"/>
         <source>Open</source>
         <translation>打开</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="84"/>
+        <location filename="../widgets/pathselection.cpp" line="95"/>
         <source>Explore</source>
         <translation>浏览</translation>
     </message>
     <message>
-        <location filename="../widgets/pathselection.cpp" line="120"/>
-        <location filename="../widgets/pathselection.cpp" line="122"/>
+        <location filename="../widgets/pathselection.cpp" line="131"/>
+        <location filename="../widgets/pathselection.cpp" line="133"/>
         <source>Select path</source>
         <translation>选择路径</translation>
     </message>
@@ -459,12 +491,12 @@ These settings might be overwritten by your Qt platform integration plugin and h
         <translation>好的</translation>
     </message>
     <message>
-        <location filename="../settingsdialog/settingsdialog.cpp" line="285"/>
+        <location filename="../settingsdialog/settingsdialog.cpp" line="320"/>
         <source>&lt;p&gt;&lt;b&gt;Errors occurred when applying changes:&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;应用更改时发生错误：&lt;/b&gt;&lt;/p&gt;&lt;ul&gt;</translation>
     </message>
     <message>
-        <location filename="../settingsdialog/settingsdialog.cpp" line="290"/>
+        <location filename="../settingsdialog/settingsdialog.cpp" line="325"/>
         <source>unknown error</source>
         <translation>未知错误</translation>
     </message>
@@ -472,22 +504,22 @@ These settings might be overwritten by your Qt platform integration plugin and h
 <context>
     <name>Utilities::windowTitle</name>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="34"/>
+        <location filename="../misc/dialogutils.cpp" line="36"/>
         <source>Unsaved - %1</source>
         <translation>未保存 - %1</translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="37"/>
+        <location filename="../misc/dialogutils.cpp" line="39"/>
         <source>%1 - %2 - %3</source>
         <translation>%1 - %2 - %3</translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="42"/>
+        <location filename="../misc/dialogutils.cpp" line="44"/>
         <source>*Unsaved - %1</source>
         <translation>*未保存 - %1</translation>
     </message>
     <message>
-        <location filename="../misc/dialogutils.cpp" line="45"/>
+        <location filename="../misc/dialogutils.cpp" line="47"/>
         <source>*%1 - %2 - %3</source>
         <translation>*%1 - %2 - %3</translation>
     </message>
